@@ -14,7 +14,7 @@
 #' @importFrom stats embed
 #' @export
 VAR = function(x, configuration=list(nlag=1)) {
-  if (class(x)!="zoo") {
+  if (!is(x, "zoo")) {
     stop("Data needs to be of type 'zoo'")
   }
   k = ncol(x)
@@ -35,6 +35,6 @@ VAR = function(x, configuration=list(nlag=1)) {
     se = rbind(se, fit$coefficients[-1,2])
     Res = cbind(Res, fit$residuals)
   }
-  Q = array(t(Res)%*%Res/nrow(Res), c(k, k, 1), dimnames=c(list(NAMES), list(NAMES), list(zoo::index(x)[nrow(x)])))
+  Q = array(t(Res)%*%Res/nrow(Res), c(k, k, 1), dimnames=list(NAMES, NAMES, tail(as.character(zoo::index(x)),1)))
   results = list(B=B, Q=Q, se=se)
 }
